#
# spec file for package rqlite
#
# Copyright (c) 2025 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rqlite
Version:        8.37.1
Release:        1.1
Summary:        Distributed relational database built on SQLite
License:        MIT
URL:            https://rqlite.io/
Source:         %{name}-%{version}.tar.xz
Source1:        vendor.tar.xz
BuildRequires:  go >= 1.22.0
BuildRequires:  golang-packaging
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(sqlite3)

%description
rqlite is a relational database which combines SQLite's simplicity with the
power of a robust, fault-tolerant, distributed system. It's designed for easy
deployment and lightweight operation, offering a developer-friendly and
operator-centric solution for multiple platforms.

%prep
%autosetup -p1 -a1

%build
export GOFLAGS="$GOFLAGS -tags=libsqlite3"
go build -mod=vendor -buildmode=pie ./cmd/rqlite
go build -mod=vendor -buildmode=pie ./cmd/rqlited
go build -mod=vendor -buildmode=pie ./cmd/rqbench

%install
install -D -m0755 rqlite %{buildroot}%{_bindir}/rqlite
install -D -m0755 rqlited %{buildroot}%{_bindir}/rqlited
install -D -m0755 rqbench %{buildroot}%{_bindir}/rqbench
install -D -m0644 tools/bash-completions/rqlite.sh %{buildroot}%{_datadir}/bash-completion/completions/rqlite
install -D -m0644 tools/bash-completions/rqlited.sh %{buildroot}%{_datadir}/bash-completion/completions/rqlited
install -D -m0644 tools/bash-completions/rqbench.sh %{buildroot}%{_datadir}/bash-completion/completions/rqbench

%files
%license LICENSE
%doc README.md
%{_bindir}/rqbench
%{_bindir}/rqlite
%{_bindir}/rqlited
%{_datadir}/bash-completion/completions/*

%changelog
* Thu May 29 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 8.37.1:
  * Prevent single-node cluster from joining another cluster
  * update dependencies
* Sun May  4 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 8.37.0:
  * Add support for automatically reloading all X.509 certificates
    and keys
* Sun Apr 20 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 8.36.18:
  * Follow redirects when building sqlite-vec
  * Support Commit Hook registration
  * Support registering Update Hooks at the database level
* Thu Apr  3 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 8.36.16:
  * Minor refactoring of HTTP Leader checks
  * Add transaction status to DB stats
* Sun Mar 16 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 8.36.14:
  * Support SQL-format loading via Follower
  * Minor refactor of HTTP credential handling
* Wed Mar 12 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 8.36.13:
  * Compress SQL-format backups during transmission
  * System-level test of SQL format backups
* Sun Mar  2 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 8.36.12:
  * Simplify random package with math/rand/v2
* Fri Feb  7 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 8.36.11:
  * Upgrade dependencies including DNS disco
  * improve logging when failing to resolve a name
* Tue Jan 28 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 8.36.10:
  * Further consistent use of HTTP client in rqlite shell
* Mon Jan 27 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 8.36.9:
  * Use configured HTTP client consistently in rqlite shell
* Thu Jan 23 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 8.36.8:
  * Fix CLI panic when no hosts are available
  * Preupdate hook complex data testing
  * Support preupdate hook for row ID values only
  * Further improvements to preupdate hook code
  * Improve preupdate hook stats and error handling
  * Basic preupdate hook support at DB level
- add bash completions
* Mon Jan 20 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 8.36.6:
  * Recover from any panic during SQL parsing
  * Optimize need-to-parse logic
* Sun Jan 12 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 8.36.5:
  * bundled dependency updates
  * Fix an issue whereby SQLite extensions were not loaded under
    certain restore-from-backup scenarios
* Sun Dec 29 2024 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 8.36.3:
  * Add version information to `/nodes` output
  * Extension paths as string command-line type
  * Updates of go dependencies and developer visible changes
- build with system sqlite
* Thu Dec 19 2024 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 8.36.1:
  * Support executes as raw POST bodies
  * Improved logging
  * Minor DB-layer improvements
* Sun Nov 17 2024 andreas.stieger@gmx.de
- initiial version
